Index: webrtc/api/peerconnectionfactoryproxy.h |
diff --git a/webrtc/api/peerconnectionfactoryproxy.h b/webrtc/api/peerconnectionfactoryproxy.h |
index ef47cdb869afccbd90e4b2ff2f7e604eb720d92e..f60f9e9c6513e5fb13c88335a30a23aa9dad17b3 100644 |
--- a/webrtc/api/peerconnectionfactoryproxy.h |
+++ b/webrtc/api/peerconnectionfactoryproxy.h |
@@ -11,6 +11,7 @@ |
#ifndef WEBRTC_API_PEERCONNECTIONFACTORYPROXY_H_ |
#define WEBRTC_API_PEERCONNECTIONFACTORYPROXY_H_ |
+#include <memory> |
#include <string> |
#include <utility> |
@@ -22,13 +23,13 @@ namespace webrtc { |
BEGIN_SIGNALING_PROXY_MAP(PeerConnectionFactory) |
PROXY_METHOD1(void, SetOptions, const Options&) |
// Can't use PROXY_METHOD5 because scoped_ptr must be moved. |
// TODO(tommi,hbos): Use of templates to support scoped_ptr? |
rtc::scoped_refptr<PeerConnectionInterface> CreatePeerConnection( |
const PeerConnectionInterface::RTCConfiguration& a1, |
const MediaConstraintsInterface* a2, |
- rtc::scoped_ptr<cricket::PortAllocator> a3, |
- rtc::scoped_ptr<DtlsIdentityStoreInterface> a4, |
+ std::unique_ptr<cricket::PortAllocator> a3, |
+ std::unique_ptr<DtlsIdentityStoreInterface> a4, |
PeerConnectionObserver* a5) override { |
return signaling_thread_ |
->Invoke<rtc::scoped_refptr<PeerConnectionInterface>>( |
@@ -37,8 +38,8 @@ BEGIN_SIGNALING_PROXY_MAP(PeerConnectionFactory) |
} |
rtc::scoped_refptr<PeerConnectionInterface> CreatePeerConnection( |
const PeerConnectionInterface::RTCConfiguration& a1, |
- rtc::scoped_ptr<cricket::PortAllocator> a3, |
- rtc::scoped_ptr<DtlsIdentityStoreInterface> a4, |
+ std::unique_ptr<cricket::PortAllocator> a3, |
+ std::unique_ptr<DtlsIdentityStoreInterface> a4, |
PeerConnectionObserver* a5) override { |
return signaling_thread_ |
->Invoke<rtc::scoped_refptr<PeerConnectionInterface>>( |
@@ -77,8 +78,8 @@ BEGIN_SIGNALING_PROXY_MAP(PeerConnectionFactory) |
cricket::PortAllocator* a3, |
DtlsIdentityStoreInterface* a4, |
PeerConnectionObserver* a5) { |
- rtc::scoped_ptr<cricket::PortAllocator> ptr_a3(a3); |
- rtc::scoped_ptr<DtlsIdentityStoreInterface> ptr_a4(a4); |
+ std::unique_ptr<cricket::PortAllocator> ptr_a3(a3); |
+ std::unique_ptr<DtlsIdentityStoreInterface> ptr_a4(a4); |
return c_->CreatePeerConnection(a1, a2, std::move(ptr_a3), |
std::move(ptr_a4), a5); |
} |
@@ -88,8 +89,8 @@ BEGIN_SIGNALING_PROXY_MAP(PeerConnectionFactory) |
cricket::PortAllocator* a3, |
DtlsIdentityStoreInterface* a4, |
PeerConnectionObserver* a5) { |
- rtc::scoped_ptr<cricket::PortAllocator> ptr_a3(a3); |
- rtc::scoped_ptr<DtlsIdentityStoreInterface> ptr_a4(a4); |
+ std::unique_ptr<cricket::PortAllocator> ptr_a3(a3); |
+ std::unique_ptr<DtlsIdentityStoreInterface> ptr_a4(a4); |
return c_->CreatePeerConnection(a1, std::move(ptr_a3), std::move(ptr_a4), |
a5); |
} |
@@ -22,13 +23,13 @@ namespace webrtc { |
BEGIN_SIGNALING_PROXY_MAP(PeerConnectionFactory) |
PROXY_METHOD1(void, SetOptions, const Options&) |
- // Can't use PROXY_METHOD5 because scoped_ptr must be moved. |
- // TODO(tommi,hbos): Use of templates to support scoped_ptr? |
+ // Can't use PROXY_METHOD5 because unique_ptr must be moved. |
+ // TODO(tommi,hbos): Use of templates to support unique_ptr? |
rtc::scoped_refptr<PeerConnectionInterface> CreatePeerConnection( |
const PeerConnectionInterface::RTCConfiguration& a1, |